<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Customers;


class CustomerController extends Controller
{
    public function register(Request $request)
    {
        $request->validate([
            'phone_number' => 'required|unique:customers',
            'username' => 'required|unique:customers',
            'email' => 'required|email|unique:customers',
            'password' => 'required|min:6',
        ]);

        $customer = Customers::create([
            'phone_number' => $request->phone_number,
            'username' => $request->username,
            'email' => $request->email,
            'password' => bcrypt($request->password),
        ]);

        return response()->json(['message' => 'Customer registered successfully', 'customers' => $customer], 201);
    }

    public function getProfile($id)
    {
        $customer = Customers::findOrFail($id);
        return response()->json(['customers' => $customer], 200);
    }

    public function updateProfile(Request $request, $id)
    {
        $customer = Customers::findOrFail($id);

        $request->validate([
            'phone_number' => 'required|unique:customers,phone_number,'.$customer->id,
            'username' => 'required|unique:customers,username,'.$customer->id,
            'email' => 'required|email|unique:customers,email,'.$customer->id,
        ]);

        $customer->update([
            'phone_number' => $request->phone_number,
            'username' => $request->username,
            'email' => $request->email,
        ]);

        return response()->json(['message' => 'Profile updated successfully', 'customers' => $customer], 200);
    }

    public function changePassword(Request $request, $id)
    {
        $request->validate([
            'new_password' => 'required|min:6|different:current_password',
            'confirm_password' => 'required|same:new_password',
        ]);

        $customer = Customers::findOrFail($id);

        $customer->update([
            'password' => bcrypt($request->new_password),
        ]);

        return response()->json(['message' => 'Password changed successfully'], 200);
    }
}
