<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Banner;

class BannerController extends Controller
{
    public function index(){

        $banner = Banner::all();
        return view('admin.banners.index',compact('banner'));
}    

public function addBanner(){

        return view('admin.banners.add');
}

public function saveBanner(Request $request){
    request()->validate([
        'title'  =>  'required|string|max:255',
        'image' =>  'required|image|mimes:jpeg,png,jpg',
    ]);
    try {

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $directory = 'Uploads/banners';
            $filename = uniqid() . '_' . time() . '.' . $image->getClientOriginalExtension();
            $image->move(public_path($directory), $filename);

            $banner = Banner::create([
                'title' => $request->title,
                'image' => $directory . '/' . $filename, // Save the path to the image
            ]);
            if ($banner) {
                return redirect()->back()->with('success', 'Successfully saved Banner');
            } else {
                return redirect()->back()->with('failed', 'Failed to save Banner');
            }
        } else {
            return redirect()->back()->with('failed', 'No image uploaded');
        }
    } catch (\Exception $exception) {
        return redirect()->back()->with('error', 'Oops, an error occurred: ' . $exception->getMessage());
    }

}

public function editBanner($id)
{
    $banner = Banner::findOrFail($id);
    return view('admin.banners.edit', compact('banner'));
}

public function updateBanner(Request $request, $id)
{
    $request->validate([
        'title' => 'required|string|max:255',
        'image' => 'nullable|image|mimes:jpeg,png,jpg',
    ]);

    try {
        $banner = Banner::findOrFail($id);

        // Update title
        $banner->title = $request->title;

        // Update image if a new image is uploaded
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $directory = 'uploads/banners';
            $filename = uniqid() . '_' . time() . '.' . $image->getClientOriginalExtension();
            $image->move(public_path($directory), $filename);
            $banner->image = $directory . '/' . $filename;
        }

        $banner->save();

        return redirect()->back()->with('success', 'Banner updated successfully');
    } catch (\Exception $exception) {
        return redirect()->back()->with('error', 'Oops! Something went wrong: ' . $exception->getMessage());
    }
}

public function deleteBanner($id)
{
    $banner = Banner::findOrFail($id);

    try {
        $banner->delete();

        return redirect()->back()->with('success', 'Banner deleted successfully');
    } catch (\Exception $exception) {
        return redirect()->back()->with('error', 'Oops! Something went wrong: ' . $exception->getMessage());
    }
}

}

