<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Category;


class CategoryController extends Controller
{
    public function index()
    {
        $category = Category::all();
        // dd($category);
        return view('admin.product.category.index',compact('category'));
    }

    public function add(){

        return view('admin.product.category.add');
    }

    public function store(Request $request){
        try {
            // Validate the request
            $validatedData = $request->validate([
                'name'  =>  'required|string|max:255',
            ]);
    
            // Check if 'status' is present in the request, if so, set its value, otherwise set it to 0
            $status = $request->has('status') ? 1 : 0;
    
            // Merge the 'status' value into the validated data
            $validatedData = array_merge($validatedData, ['status' => $status]);
    
            // Create the category
            $category = Category::create($validatedData);
    
            // Check if category creation was successful
            if($category) {
                return redirect()->route('product.category')->with('success','Successfully saved category');
            } else {
                return redirect()->route('product.category')->with('failed','Failed to save category');
            }
        } catch (\Exception $exception) {
            // Log the error for debugging
            \Log::error('Error while saving category: ' . $exception->getMessage());
    
            // Redirect back with an error message
            return redirect()->back()->with('error','Oops! Something went wrong.');
        }
    }

    public function edit($category_id){
        $category = Category::find($category_id);
        return view ('admin.product.category.edit',compact('category'));
    }

    public function update(Request $request)
    {
        request()->validate([
            'name'  =>  'required|string|max:255',
        ]);
        $category = Category::where('id', $request->category_id)->first();
        if(isset($category)):
            try {
                $categoryUpdate = Category::where('id', $request->category_id)->update(['name' => $request->name,'status' => $request->status == true ? '1':'0']);
                if($categoryUpdate > 0):
                    return redirect()->route('product.category')->with('success','Successfully updated category');
                else:
                    return redirect()->back()->with('failed','Failed to update category');
                endif;
            }catch (\Exception $exception) {
                return redirect()->back()->with('error','Oop\'s error : '.$exception->getMessage());
            }
        else:
            return redirect()->back()->with('failed','invalid request to update category');
        endif;
    }

    public function delete($id)
    {
        $category = Category::findOrFail($id);

        try {
            $category->delete();

            return redirect()->back()->with('success', 'Category deleted successfully');
        } catch (\Exception $exception) {
            return redirect()->back()->with('error', 'Oops! Something went wrong: ' . $exception->getMessage());
        }
    }
    
}

