<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\ProductModel;
use App\Models\Category;


class ProductModelController extends Controller
{
    public function index(){
        $model = ProductModel::orderBy('id','DESC')->get();
        $categories = Category::with('model')->get();  
        return view('admin.product.product-model.index',compact('model','categories'));
    }
    public function add(){

        $categories = Category::with('model')->get();  
        return view('admin.product.product-model.add',compact('categories'));
    }
    public function store(Request $request)
    {
        // Validate the request data
        $request->validate([
            'category_id' => 'required|exists:categories,id',
            'product_model' => 'required|string|max:255',
        ]);

        try {
            $model = ProductModel::create([
                'category_id'=>$request->category_id,
                'product_model'=>$request->product_model,
                ])->id;
            // Redirect back with success message
            return redirect()->route('product.model')->with('success', 'Product model added successfully');
        } catch (\Exception $exception) {
            // If an exception occurs, redirect back with error message
            return redirect()->back()->with('error', 'Failed to add Product Model: ' . $exception->getMessage());
        }
    }
    public function edit($id)
    {
        $model = ProductModel::findOrFail($id);
        $categories = Category::all();
        return view('admin.product.product-model.edit', compact('model', 'categories'));
    }

    public function update(Request $request)
    {
    $model = ProductModel::where('id', $request->id)->first();
    $model_update = ProductModel::where('id', $model->id)->update([
        'category_id'=>$request->category_id, 
        'product_model'=>$request->product_model,
    ]);
    if($model_update > 0):
    return redirect()->route('product.model')->with('success','Successfully updated Product Model');
    else:
        return redirect()->back()->with('failed','Failed to update Product Model details');
    endif;
    }

    public function delete($id)
{
    $model = ProductModel::findOrFail($id);

    try {
        $model->delete();

        return redirect()->back()->with('success', 'Product Model deleted successfully');
    } catch (\Exception $exception) {
        return redirect()->back()->with('error', 'Oops! Something went wrong: ' . $exception->getMessage());
    }
}
}
