<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\IndexController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\BannerController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\ProductModelController;
use App\Http\Controllers\TermsController;
use App\Http\Middleware\AuthMiddleware;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Route::get('/', function () {
//     return view('welcome');
// });

Route::get('/login', [AuthController::class, 'index'])->name('login');
Route::post('/loginAccess', [AuthController::class, 'loginAccess'])->name('login.access');

Route::get('signout', [AuthController::class, 'signout'])->name('signout');

Route::group(['middleware' => 'auth'], function () {

    Route::get('/dashboard', [IndexController::class, 'Dashboard'])->name('dashboard');

    //category
    Route::get('product-category', [CategoryController::class, 'index'])->name('product.category'); 
    Route::get('add-category', [CategoryController::class, 'add'])->name('product.category.add'); 
    Route::post('save-category', [CategoryController::class, 'store'])->name('product.category.save'); 
    Route::get('edit-category/{category_id}', [CategoryController::class, 'edit'])->name('product.category.edit');
    Route::post('update-category/{category_id}', [CategoryController::class, 'update'])->name('product.category.update');
    Route::delete('delete-category/{id}', [CategoryController::class, 'delete'])->name('delete.category');

    //product Model
    Route::get('product-model', [ProductModelController::class, 'index'])->name('product.model'); 
    Route::get('add-model', [ProductModelController::class, 'add'])->name('product.add');
    Route::post('save-model', [ProductModelController::class, 'store'])->name('product.save');
    Route::get('edit-model/{id}', [ProductModelController::class, 'edit'])->name('product.model.edit');
    Route::post('update-model/{id}', [ProductModelController::class, 'update'])->name('product.model.update');
    Route::delete('delete-model/{id}', [ProductModelController::class, 'delete'])->name('delete.model');



    //Banners
    Route::get('banners', [BannerController::class, 'index'])->name('banners'); 
    // Route::get('/add-banners', [IndexController::class, 'Addbannerform'])->name('addbannerform');
    Route::get('add-banner', [BannerController::class, 'addBanner'])->name('add.banner'); 
    Route::post('save-banner', [BannerController::class, 'saveBanner'])->name('save.banner'); 
    Route::get('banners/{id}/edit', [BannerController::class, 'editBanner'])->name('edit.banner');
    Route::post('banners/{id}/update', [BannerController::class, 'updateBanner'])->name('update.banner');
    Route::delete('delete-banner/{id}', [BannerController::class, 'deleteBanner'])->name('delete.banner');
    
    //Notifications
    Route::get('notifications', [NotificationController::class, 'index'])->name('notifications'); 
    Route::get('add-notification', [NotificationController::class, 'addNotification'])->name('add.notification'); 
    Route::post('save-notification', [NotificationController::class, 'saveNotification'])->name('save.notification'); 


    //Terms and Conditions
    Route::get('terms', [TermsController::class, 'index'])->name('terms'); 
    Route::get('add-term', [TermsController::class, 'addTerm'])->name('add.terms'); 
    Route::post('save-term', [TermsController::class, 'saveTerm'])->name('save.terms'); 
    Route::get('edit-terms/{id}', [TermsController::class, 'edit'])->name('terms.edit');
    Route::post('update-terms/{id}', [TermsController::class, 'update'])->name('terms.update');
 
});


